Ziņojumi | OiRA

Temati

# Ziņojumi

Ziņojumu varat izmantot, lai:

- sniegtu pierādījumus uzraudzības iestādēm,
- nodotu informāciju attiecīgajām personām (darba ņēmējiem, drošības pārstāvjiem, darba devējiem, darba drošības un veselības aizsardzības ekspertiem u. tml.),
- uzraudzītu un novērtētu, vai ir ieviesti nepieciešamie pasākumi,
- reģistrētu labojumus, ja mainās apstākļi (jaunas mašīnas/darba ņēmēji vai tiek izdarīti konstatējumi jebkādu negadījumu izmeklēšanas rezultātā u. tml.).

Jūs varat saglabāt ziņojumu savā datorā un izdrukāt to. Jūs varat arī to mainīt vai pievienot papildu informāciju. Ņemiet vērā, ka jebkuras izmaiņas, kas veiktas jūsu lejupielādētajā ziņojumā, NETIKS saglabātas OiRA rīkā.

## Ziņojumu izvēles

Ir pieejami dažāda veida ziņojumi dažādiem mērķiem. Konkrētiem rīkiem pieejamo ziņojumu atlase ir atkarīga no lēmumiem, ko pieņēmis valsts OiRA partneris / rīka izstrādātājs.

Pieejamie ziņojumi.

### Pilns ziņojums

Formāts: Word / Office Open XML (.docx). Var rediģēt pēc lejupielādes.

Sniedz: visu informāciju un informāciju, ko ievadījāt riska novērtēšanas procesā.

Izmantojiet to, lai: sniegtu pierādījumus par riska novērtējumu uzraudzības iestādēm (piemēram, darba inspekcijai).

### Rīcības plāns

Formāts: Excel/Office Open XML (.xlsx). Var rediģēt pēc lejupielādes.

Sniedz: informāciju par visiem pasākumiem, ko izvēlējāties īstenot.

Izmantojiet to, lai:

- aktīvi sekotu līdzi izvēlēto pasākumu īstenošanai,
- pārvaldītu problēmas/riskus jūsu darba vietā (konkrētus uzdevumus, zināšanas, pienākumus, termiņus).

### Risku pārskats

Formāts: Pārnesams dokumentu formāts (.pdf) Nevar rediģēt pēc lejupielādes.

Sniedz: identificēto risku pārskatu

Izmantojiet to, lai:

- gūtu ātru pārskatu par risku stāvokli jūsu darba vietā,
- nodotu informāciju attiecīgajām personām,
- uzraudzītu, vai riskus/pasākumus pienācīgi risina.

### Pasākumu pārskats

Formāts: Pārnesams dokumentu formāts (.pdf) Nevar rediģēt pēc lejupielādes.

Sniedz: ātru pārskatu par īstenojamiem pasākumiem.

Izmantojiet to, lai:

- gūtu ātru pārskatu par to pasākumu statusu, ko esat nolēmis īstenot,
- nodotu informāciju attiecīgajām personām,
- uzraudzītu, vai riskus/pasākumus pienācīgi risina.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More